@@ -5,7 +5,7 @@ package Data::Tubes::Util;
 use strict;
 use warnings;
 use Exporter 'import';
-our $VERSION = '0.722';
+our $VERSION = '0.724';
 
 use Log::Log4perl::Tiny qw< :easy :dead_if_first >;
 
@@ -22,6 +22,7 @@ our @EXPORT_OK = qw<
   sprintffy
   test_all_equal
   traverse
+  tube
   unzip
 >;
 
@@ -224,6 +225,11 @@ sub traverse {
    return $data;
 } ## end sub traverse
 
+sub tube {
+   my $locator = shift;
+   return load_sub($locator)->(@_);
+} ## end sub tube
+
 sub unzip {
    my $items = (@_ && ref($_[0])) ? $_[0] : \@_;
    my $n_items = scalar @$items;
